==> vod-common-1.0.0-sources.jar: com/valor/vod/common/model/token/ServiceToken.java <==
package com.valor.vod.common.model.token;

import com.google.common.base.Joiner;
import com.google.common.base.Splitter;
import com.google.common.base.Strings;
import com.valor.vod.api.common.client.IStringSerializable;
import com.valor.vod.api.exception.ApiException;
import com.valor.vod.api.model.constant.response.HttpCode2;
import common.base.tools.type.CollectionUtils;

import java.io.UnsupportedEncodingException;
import java.util.List;

/**
 * Created by Frank.Huang on 2017/1/21.
 */
public class ServiceToken implements IStringSerializable {
    private static final int VER_20170121 = 20170121;
    private int version = VER_20170121;
    private String did = "";
    private String serviceCode = "";
    private Long random = System.currentTimeMillis();
    private String echoStr = "";

    public static ServiceToken valueOf(String str) throws ApiException {
        if (Strings.isNullOrEmpty(str)) {
            throw new ApiException(HttpCode2.RET_BIZ_ERR, HttpCode2.ERR_BIZ_INVALID_SERVICE_TOKEN, "Invalid service token");
        }

        List<String> valueList = Splitter.on("#!").splitToList(str);
        if (CollectionUtils.isNullOrEmpty(valueList)) {
            throw new ApiException(HttpCode2.RET_BIZ_ERR, HttpCode2.ERR_BIZ_INVALID_SERVICE_TOKEN, "Invalid service token(format,error");
        }

        ServiceToken serviceToken = new ServiceToken();

        serviceToken.setVersion(Integer.valueOf(valueList.get(0)));
        serviceToken.setDid(valueList.get(1));
        serviceToken.setServiceCode(valueList.get(2));
        serviceToken.setRandom(Long.valueOf(valueList.get(3)));
        serviceToken.setEchoStr(valueList.get(4));
        return serviceToken;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public int getVersion() {
        return version;
    }

    public void setVersion(int version) {
        this.version = version;
    }

    public String getServiceCode() {
        return serviceCode;
    }

    public void setServiceCode(String serviceCode) {
        this.serviceCode = serviceCode;
    }

    public String getEchoStr() {
        return echoStr;
    }

    public void setEchoStr(String echoStr) {
        this.echoStr = echoStr;
    }

    public Long getRandom() {
        return random;
    }

    public void setRandom(Long random) {
        this.random = random;
    }

    @Override
    public String toSerializeString() {
        return Joiner.on("#!").join(version, did, serviceCode, random, echoStr);
    }

    @Override
    public byte[] toSerializeBytes() {
        try {
            return toSerializeString().getBytes("UTF-8");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
            return new byte[0];
        }
    }

}

==> vod-common-1.0.2-sources.jar: com/valor/vod/common/model/token/ServiceToken.java <==
package com.valor.vod.common.model.token;

import com.google.common.base.Joiner;
import com.google.common.base.Splitter;
import com.google.common.base.Strings;
import com.valor.vod.api.common.client.IStringSerializable;
import com.valor.vod.api.exception.ApiException;
import com.valor.vod.api.model.constant.response.HttpCode2;
import com.valor.vod.common.tools.type.CollectionUtils;

import java.io.UnsupportedEncodingException;
import java.util.List;

/** Created by Frank.Huang on 2017/1/21. */
public class ServiceToken implements IStringSerializable {
    private static final int VER_20170121 = 20170121;
    private int version = VER_20170121;
    private String did = "";
    private String serviceCode = "";
    private Long random = System.currentTimeMillis();
    private String echoStr = "";

    public static ServiceToken valueOf(String str) throws ApiException {
        if (Strings.isNullOrEmpty(str)) {
            throw new ApiException(
                    HttpCode2.RET_BIZ_ERR,
                    HttpCode2.ERR_BIZ_INVALID_SERVICE_TOKEN,
                    "Invalid service token");
        }

        List<String> valueList = Splitter.on("#!").splitToList(str);
        if (CollectionUtils.isNullOrEmpty(valueList)) {
            throw new ApiException(
                    HttpCode2.RET_BIZ_ERR,
                    HttpCode2.ERR_BIZ_INVALID_SERVICE_TOKEN,
                    "Invalid service token(format,error");
        }

        ServiceToken serviceToken = new ServiceToken();

        serviceToken.setVersion(Integer.valueOf(valueList.get(0)));
        serviceToken.setDid(valueList.get(1));
        serviceToken.setServiceCode(valueList.get(2));
        serviceToken.setRandom(Long.valueOf(valueList.get(3)));
        serviceToken.setEchoStr(valueList.get(4));
        return serviceToken;
    }

    public String getDid() {
        return did;
    }

    public void setDid(String did) {
        this.did = did;
    }

    public int getVersion() {
        return version;
    }

    public void setVersion(int version) {
        this.version = version;
    }

    public String getServiceCode() {
        return serviceCode;
    }

    public void setServiceCode(String serviceCode) {
        this.serviceCode = serviceCode;
    }

    public String getEchoStr() {
        return echoStr;
    }

    public void setEchoStr(String echoStr) {
        this.echoStr = echoStr;
    }

    public Long getRandom() {
        return random;
    }

    public void setRandom(Long random) {
        this.random = random;
    }

    @Override
    public String toSerializeString() {
        return Joiner.on("#!").join(version, did, serviceCode, random, echoStr);
    }

    @Override
    public byte[] toSerializeBytes() {
        try {
            return toSerializeString().getBytes("UTF-8");
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
            return new byte[0];
        }
    }
}
